@@ -75,6 +75,56 @@ QA_CONFIG = {
     },
 }
 
+# API QA Agent Metadata
+API_QA_CONFIG = {
+    "name": "api_qa_agent",
+    "version": "1.0.0",
+    "type": "core_agent",
+    "capabilities": [
+        "rest_api_testing",
+        "graphql_testing",
+        "endpoint_validation",
+        "authentication_testing",
+        "authorization_testing",
+        "contract_testing",
+        "load_testing",
+        "api_performance_testing",
+    ],
+    "primary_interface": "api_testing_framework",
+    "performance_targets": {
+        "endpoint_validation": "2m",
+        "auth_flow_testing": "5m",
+        "load_testing": "10m",
+        "contract_validation": "5m",
+        "response_time_target": "200ms",
+    },
+}
+
+# Web QA Agent Metadata
+WEB_QA_CONFIG = {
+    "name": "web_qa_agent",
+    "version": "1.0.0",
+    "type": "core_agent",
+    "capabilities": [
+        "browser_automation",
+        "e2e_testing",
+        "ui_testing",
+        "responsive_testing",
+        "accessibility_testing",
+        "cross_browser_testing",
+        "performance_testing",
+        "visual_regression",
+    ],
+    "primary_interface": "browser_testing_framework",
+    "performance_targets": {
+        "e2e_test_suite": "15m",
+        "accessibility_audit": "5m",
+        "cross_browser_test": "20m",
+        "page_load_target": "2.5s",
+        "lighthouse_score": "90",
+    },
+}
+
 # Research Agent Metadata
 RESEARCH_CONFIG = {
     "name": "research_agent",
@@ -213,15 +263,44 @@ PROJECT_ORGANIZER_CONFIG = {
     },
 }
 
+# ImageMagick Agent Metadata
+IMAGEMAGICK_CONFIG = {
+    "name": "imagemagick_agent",
+    "version": "1.0.0",
+    "type": "optimization_agent",
+    "capabilities": [
+        "image_optimization",
+        "format_conversion",
+        "responsive_image_generation",
+        "batch_processing",
+        "web_performance_optimization",
+        "core_web_vitals_improvement",
+        "avif_webp_conversion",
+        "quality_compression",
+    ],
+    "primary_interface": "imagemagick_cli",
+    "performance_targets": {
+        "single_image_optimization": "30s",
+        "batch_processing_100_images": "10m",
+        "format_conversion": "10s",
+        "responsive_set_generation": "60s",
+        "file_size_reduction": "50-70%",
+        "quality_threshold": "0.95_ssim",
+    },
+}
+
 # Aggregate all configs for easy access
 ALL_AGENT_CONFIGS = {
     "documentation": DOCUMENTATION_CONFIG,
     "version_control": VERSION_CONTROL_CONFIG,
     "qa": QA_CONFIG,
+    "api_qa": API_QA_CONFIG,
+    "web_qa": WEB_QA_CONFIG,
     "research": RESEARCH_CONFIG,
     "ops": OPS_CONFIG,
     "security": SECURITY_CONFIG,
     "engineer": ENGINEER_CONFIG,
     "data_engineer": DATA_ENGINEER_CONFIG,
     "project_organizer": PROJECT_ORGANIZER_CONFIG,
+    "imagemagick": IMAGEMAGICK_CONFIG,
 }
