@@ -10,12 +10,17 @@ Part of TSK-0046: Service Layer Architecture Reorganization
 Services:
 - LoggingService: Centralized logging with structured output
 - HealthMonitor: System health monitoring and alerting
+- MemoryGuardian: Memory monitoring and process restart management
 """
 
+from .health_monitor import HealthMonitor
 from .logging import LoggingService
-from .monitoring import HealthMonitor
+from .memory_guardian import MemoryGuardian
+from .monitoring import AdvancedHealthMonitor
 
 __all__ = [
-    'LoggingService',
-    'HealthMonitor',
-]
\ No newline at end of file
+    "AdvancedHealthMonitor",  # For SocketIO server monitoring
+    "HealthMonitor",  # For Memory Guardian system monitoring
+    "LoggingService",
+    "MemoryGuardian",
+]
