@@ -10,14 +10,12 @@ to create focused, maintainable modules.
 """
 
 import asyncio
-import logging
-import os
 import threading
 import time
 from collections import deque
 from datetime import datetime
 from pathlib import Path
-from typing import Any, Dict, List, Optional, Set
+from typing import Any, Dict, Set
 
 try:
     import aiohttp
@@ -32,16 +30,15 @@ except ImportError:
     web = None
 
 # Import VersionService for dynamic version retrieval
+import contextlib
+
 from claude_mpm.services.version_service import VersionService
 
 from ....core.constants import (
-    NetworkConfig,
-    PerformanceConfig,
     SystemLimits,
     TimeoutConfig,
 )
-from ....core.interfaces import SocketIOServiceInterface
-from ....core.logging_config import get_logger, log_operation, log_performance_context
+from ....core.logging_config import get_logger
 from ....core.unified_paths import get_project_root, get_scripts_dir
 from ...exceptions import SocketIOServerError as MPMConnectionError
 
@@ -87,7 +84,7 @@ class SocketIOServerCore:
 
         # Static files path
         self.static_path = None
-        
+
         # Heartbeat task
         self.heartbeat_task = None
         self.heartbeat_interval = 60  # seconds
@@ -145,7 +142,7 @@ class SocketIOServerCore:
             # condition window where other threads might try to access it.
             self.loop = asyncio.new_event_loop()
             asyncio.set_event_loop(self.loop)
-            
+
             self.logger.debug("Event loop created and set for background thread")
 
             # Run the server
@@ -167,7 +164,7 @@ class SocketIOServerCore:
                 logger=False,  # Disable Socket.IO's own logging
                 engineio_logger=False,
                 ping_interval=25,  # Send ping every 25 seconds
-                ping_timeout=60,   # Wait 60 seconds for pong response
+                ping_timeout=60,  # Wait 60 seconds for pong response
                 max_http_buffer_size=1e8,  # 100MB max buffer
             )
 
@@ -215,10 +212,8 @@ class SocketIOServerCore:
             # Cancel heartbeat task
             if self.heartbeat_task and not self.heartbeat_task.done():
                 self.heartbeat_task.cancel()
-                try:
+                with contextlib.suppress(asyncio.CancelledError):
                     await self.heartbeat_task
-                except asyncio.CancelledError:
-                    pass
                 self.logger.info("Stopped system heartbeat task")
 
             if self.site:
@@ -240,43 +235,48 @@ class SocketIOServerCore:
             # Add debug logging for deployment context
             try:
                 from ....core.unified_paths import PathContext
+
                 deployment_context = PathContext.detect_deployment_context()
-                self.logger.debug(f"Setting up static files in {deployment_context.value} mode")
+                self.logger.debug(
+                    f"Setting up static files in {deployment_context.value} mode"
+                )
             except Exception as e:
                 self.logger.debug(f"Could not detect deployment context: {e}")
-            
+
             self.dashboard_path = self._find_static_path()
 
             if self.dashboard_path and self.dashboard_path.exists():
                 self.logger.info(f"✅ Dashboard found at: {self.dashboard_path}")
-                
+
                 # Serve index.html at root
                 async def index_handler(request):
                     index_file = self.dashboard_path / "index.html"
                     if index_file.exists():
                         self.logger.debug(f"Serving dashboard index from: {index_file}")
                         return web.FileResponse(index_file)
-                    else:
-                        self.logger.warning(f"Dashboard index.html not found at: {index_file}")
-                        return web.Response(text="Dashboard not available", status=404)
+                    self.logger.warning(
+                        f"Dashboard index.html not found at: {index_file}"
+                    )
+                    return web.Response(text="Dashboard not available", status=404)
 
                 self.app.router.add_get("/", index_handler)
-                
+
                 # Serve version.json from dashboard directory
                 async def version_handler(request):
                     version_file = self.dashboard_path / "version.json"
                     if version_file.exists():
                         self.logger.debug(f"Serving version.json from: {version_file}")
                         return web.FileResponse(version_file)
-                    else:
-                        # Return default version info if file doesn't exist
-                        return web.json_response({
+                    # Return default version info if file doesn't exist
+                    return web.json_response(
+                        {
                             "version": "1.0.0",
                             "build": 1,
                             "formatted_build": "0001",
-                            "full_version": "v1.0.0-0001"
-                        })
-                
+                            "full_version": "v1.0.0-0001",
+                        }
+                    )
+
                 self.app.router.add_get("/version.json", version_handler)
 
                 # Serve static assets (CSS, JS) from the dashboard static directory
@@ -287,12 +287,17 @@ class SocketIOServerCore:
                     self.app.router.add_static(
                         "/static/", dashboard_static_path, name="dashboard_static"
                     )
-                    self.logger.info(f"✅ Static assets available at: {dashboard_static_path}")
+                    self.logger.info(
+                        f"✅ Static assets available at: {dashboard_static_path}"
+                    )
                 else:
-                    self.logger.warning(f"⚠️  Static assets directory not found at: {dashboard_static_path}")
+                    self.logger.warning(
+                        f"⚠️  Static assets directory not found at: {dashboard_static_path}"
+                    )
 
             else:
                 self.logger.warning("⚠️  No dashboard found, serving fallback response")
+
                 # Fallback handler
                 async def fallback_handler(request):
                     return web.Response(
@@ -301,18 +306,20 @@ class SocketIOServerCore:
                     )
 
                 self.app.router.add_get("/", fallback_handler)
-                
+
         except Exception as e:
             self.logger.error(f"❌ Error setting up static files: {e}")
             import traceback
+
             self.logger.debug(f"Static file setup traceback: {traceback.format_exc()}")
-            
+
             # Ensure we always have a basic handler
             async def error_handler(request):
                 return web.Response(
                     text="Socket.IO server running - Static files unavailable",
                     status=200,
                 )
+
             self.app.router.add_get("/", error_handler)
 
     def _find_static_path(self):
@@ -324,16 +331,17 @@ class SocketIOServerCore:
         # Get deployment-context-aware paths
         try:
             from ....core.unified_paths import get_path_manager
+
             path_manager = get_path_manager()
-            
+
             # Use package root for installed packages (including pipx)
             package_root = path_manager.package_root
             self.logger.debug(f"Package root: {package_root}")
-            
+
             # Use project root for development
             project_root = get_project_root()
             self.logger.debug(f"Project root: {project_root}")
-            
+
         except Exception as e:
             self.logger.debug(f"Could not get path manager: {e}")
             package_root = None
@@ -345,7 +353,6 @@ class SocketIOServerCore:
             package_root / "dashboard" / "templates" if package_root else None,
             package_root / "services" / "socketio" / "static" if package_root else None,
             package_root / "static" if package_root else None,
-            
             # Project-based paths (for development)
             project_root / "src" / "claude_mpm" / "dashboard" / "templates",
             project_root / "dashboard" / "templates",
@@ -353,15 +360,12 @@ class SocketIOServerCore:
             project_root / "src" / "claude_mpm" / "services" / "socketio" / "static",
             project_root / "static",
             project_root / "src" / "static",
-            
             # Package installation locations (fallback)
             Path(__file__).parent.parent / "static",
             Path(__file__).parent / "static",
-            
             # Scripts directory (for standalone installations)
             get_scripts_dir() / "static",
             get_scripts_dir() / "socketio" / "static",
-            
             # Current working directory
             Path.cwd() / "static",
             Path.cwd() / "socketio" / "static",
@@ -369,7 +373,9 @@ class SocketIOServerCore:
 
         # Filter out None values
         possible_paths = [p for p in possible_paths if p is not None]
-        self.logger.debug(f"Searching {len(possible_paths)} possible static file locations")
+        self.logger.debug(
+            f"Searching {len(possible_paths)} possible static file locations"
+        )
 
         for path in possible_paths:
             self.logger.debug(f"Checking for static files at: {path}")
@@ -379,14 +385,15 @@ class SocketIOServerCore:
                     if (path / "index.html").exists():
                         self.logger.info(f"✅ Found static files at: {path}")
                         return path
-                    else:
-                        self.logger.debug(f"Directory exists but no index.html: {path}")
+                    self.logger.debug(f"Directory exists but no index.html: {path}")
                 else:
                     self.logger.debug(f"Path does not exist: {path}")
             except Exception as e:
                 self.logger.debug(f"Error checking path {path}: {e}")
 
-        self.logger.warning("⚠️  Static files not found - dashboard will not be available")
+        self.logger.warning(
+            "⚠️  Static files not found - dashboard will not be available"
+        )
         self.logger.debug(f"Searched paths: {[str(p) for p in possible_paths]}")
         return None
 
@@ -409,10 +416,10 @@ class SocketIOServerCore:
             True if server is active
         """
         return self.running
-    
+
     async def _heartbeat_loop(self):
         """Send periodic heartbeat events to connected clients.
-        
+
         WHY: This provides a way to verify the event flow is working and
         track server health and active sessions without relying on hook events.
         """
@@ -420,23 +427,27 @@ class SocketIOServerCore:
             try:
                 # Wait for the interval
                 await asyncio.sleep(self.heartbeat_interval)
-                
+
                 if not self.sio:
                     continue
-                    
+
                 # Calculate uptime
                 uptime_seconds = 0
                 if self.stats.get("start_time"):
-                    uptime_seconds = int((datetime.now() - self.stats["start_time"]).total_seconds())
-                
+                    uptime_seconds = int(
+                        (datetime.now() - self.stats["start_time"]).total_seconds()
+                    )
+
                 # Get active sessions from main server if available
                 active_sessions = []
-                if self.main_server and hasattr(self.main_server, 'get_active_sessions'):
+                if self.main_server and hasattr(
+                    self.main_server, "get_active_sessions"
+                ):
                     try:
                         active_sessions = self.main_server.get_active_sessions()
                     except Exception as e:
                         self.logger.debug(f"Could not get active sessions: {e}")
-                
+
                 # Prepare heartbeat data (using new schema)
                 heartbeat_data = {
                     "type": "system",
@@ -454,20 +465,20 @@ class SocketIOServerCore:
                         },
                     },
                 }
-                
+
                 # Add to event history if main server is available
-                if self.main_server and hasattr(self.main_server, 'event_history'):
+                if self.main_server and hasattr(self.main_server, "event_history"):
                     self.main_server.event_history.append(heartbeat_data)
-                
+
                 # Emit heartbeat to all connected clients (already using new schema)
                 await self.sio.emit("system_event", heartbeat_data)
-                
+
                 self.logger.info(
                     f"System heartbeat sent - clients: {len(self.connected_clients)}, "
                     f"uptime: {uptime_seconds}s, events: {self.stats.get('events_sent', 0)}, "
                     f"sessions: {len(active_sessions)}"
                 )
-                
+
             except asyncio.CancelledError:
                 # Task was cancelled, exit gracefully
                 break
